==> clickandpledge_connect-8.x-1.2002000101.tar.gz: clickandpledge_connect/src/Form/CnPpledgeTVChannels.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Uses to display pledgeTV channels in a table.
 */
class CnPpledgeTVChannels extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The class Constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The Database connection.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpcaccount_pledgetv_channels';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = $this->displaypledgeTvChannelsForm($form, $form_state);
    return $form;
  }

  /**
   * Displays pledgeTV channels into a table.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure
   */
  public function displaypledgeTvChannelsForm(array $form, $form_state) {
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>
                                    <li><a href="cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                                    <li><a href="cnp_form">' . $this->t("Form Groups") . '</a></li>
      <li><a class="cnpccurrent" href="CnPpledgeTVChannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                                    <li><a href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                                    </ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $html = '<div class="cnpc-btn-center"><a href="add_channel_group" class="cnpc_button_link_add">' . $this->t("Add New Channel Group") . '</a></div>';

    $form['button_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['table_group_start'] = [
      '#prefix' => '<div class="tablelist_group">',
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_tag_start'] = [
        '#prefix' => '<div><table id="table_form_group" class="table_form_group">
                            <thead>
                                <tr>
                                                          <th>' . $this->t('Group Name') . '</th>
                                                          <th>' . $this->t('Account#') . '</th>
                                  <th>Short Code <span class="cnpc_question">&#63;</span><div class="cnpc_shortcode_tooltip">Please copy this code and place it in your required content pages, posts or any custom content types. This code will run the series of the channels which has been added to this particular channel Group inside your content page.</div></th>
                                                          <th>' . $this->t('Start Date/Time') . '</th>
                                                          <th>' . $this->t('End Date/Time') . '</th>
                                                          <th>' . $this->t('Active Channel(s)') . '</th>
                                                          <th>' . $this->t('Last Modified') . '</th>
                                                          <th>' . $this->t('Status') . '</th>
                                                          <th>' . $this->t('Actions') . '</th>
                                </tr>
                            </thead>
                                                  <tbody>',
      ];
      $channelGroups = $this->getRecords();
      $rg = 1;
      foreach ($channelGroups as $fg) {
        if ($fg->cnpchannelgrp_channel_EndDate == '0000-00-00 00:00:00') {
          $enddate = '';
        }
        else {
          $enddate = date('F d, Y h:i:s a', strtotime($fg->cnpchannelgrp_channel_EndDate));
        }
        if ($this->checkFormsExpiry($fg->cnpchannelgrp_channel_StartDate, $enddate) === 'no') {
          $flink = "<a id='formstatus_" . $fg->cnpchannelgrp_ID . "' class='ptvformstatus' href='' data-fgid='" . $fg->cnpchannelgrp_ID . "' data-fstatus='" . $fg->cnpchannelgrp_status . "'>" . $fg->cnpchannelgrp_status . "</a>";
        }
        else {
          $flink = "<a class='ptvformstatus' href=''>" . $this->t("Expired") . "</a>";
        }
        $form['table_row_form_groups_' . $rg] = [
          '#prefix' => '<tr>
                                              <td>' . $fg->cnpchannelgrp_groupname . '</td>
                                              <td>' . $fg->cnpstngs_AccountNumber . '</td>
                                              <td>' . $fg->cnpchannelgrp_shortcode . '</td>
                                              <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpchannelgrp_channel_StartDate)) . '</td>
                                              <td>' . $enddate . '</td>
                                              <td>' . count($this->getNoofChannels($fg->cnpchannelgrp_ID)) . '</td>
                                              <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpchannelgrp_Date_Modified)) . '</td>
                                              <td>' . $flink . '</td>
                                              <td><a href="viewchannels/' . $fg->cnpchannelgrp_ID . '"><span class="view_icon"></span></a> | <a href="editchannels/' . $fg->cnpchannelgrp_ID . '"><span class="edit_icon"></span></a> | <a id="deletechannelInfo" class="deletechannelInfo" data-recid="' . $fg->cnpchannelgrp_ID . '" href="#"><span class="bin_icon"></span></a> </td>',
          '#suffix' => '</tr>',
        ];
        $rg++;
      }
      $form['table_tag_end'] = [
        '#suffix' => '</tbody></table></div>',
      ];
    }
    else {
      $form['no_records'] = [
        '#prefix' => '<div><h3>' . $this->t("No Records Found.") . '</h3>',
        '#suffix' => '</div>',
      ];
    }
    $form['table_group_end'] = [
      '#suffix' => '</div>',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Saving form data handling with ajax call.
  }

  /**
   * Get pledgeTV channels from db to display into a table.
   *
   * @return array
   *   Returns channel and its settings information as an array.
   */
  public function getRecords() {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channelgrp';
    $settingstable_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT * FROM " . $table_name . " INNER JOIN " . $settingstable_name . " ON cnpchannelgrp_cnpstngs_ID=cnpstngs_ID";
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * To get the total no of channels under a form group.
   *
   * @param int $id
   *   The Channel group ID.
   *
   * @return array
   *   Returns all the channels in an array.
   */
  public function getNoofChannels($id) {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channeldtl';
    $sql = "SELECT cnpchannel_id,cnpchannel_cnpchannelgrp_ID,cnpchannel_channelName,cnpchannel_channelStartDate,"
      . "cnpchannel_channelEndDate,cnpchannel_channelStatus,cnpchannel_DateCreated,"
      . "cnpchannel_DateModified FROM " . $table_name . " where cnpchannel_cnpchannelgrp_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * Calculates expiry date of a form.
   *
   * @param mixed $startDT
   *   The Start date.
   * @param mixed $endDT
   *   The End date.
   *
   * @return string
   *   Return yes if the form is expired otherwise returns no.
   */
  public function checkFormsExpiry($startDT, $endDT) {
    date_default_timezone_set(drupal_get_user_timezone());
    $currDT = date('Y-m-d h:i:s a');
    $currDT = strtotime($currDT);
    $startDT = strtotime($startDT);
    $endDT = strtotime($endDT);
    if ($startDT > $currDT) {
      return 'no';
    }
    if ($endDT) {
      if (($currDT >= $startDT) && ($currDT <= $endDT)) {
        return 'no';
      }
      else {
        return 'yes';
      }
    }
    else {
      return 'no';
    }
  }

}

==> clickandpledge_connect-8.x-1.2003000101.tar.gz: clickandpledge_connect/src/Form/CnPpledgeTVChannels.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;
use Drupal\Core\Access\CsrfTokenGenerator;

/**
 * Uses to display pledgeTV channels in a table.
 */
class CnPpledgeTVChannels extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The CSRF token generator.
   *
   * @var \Drupal\Core\Access\CsrfTokenGenerator
   */
  protected $csrfToken;

  /**
   * The class constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The Database connection.
   * @param \Drupal\Core\Access\CsrfTokenGenerator $csrf_token
   *   The CSRF token generator.
   */
  public function __construct(Connection $connection, CsrfTokenGenerator $csrf_token) {
    $this->connection = $connection;
    $this->csrfToken = $csrf_token;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'), $container->get('csrf_token')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpcaccount_pledgetv_channels';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = $this->displaypledgeTvChannelsForm($form, $form_state);
    return $form;
  }

  /**
   * Displays pledgeTV channels into a table.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure
   */
  public function displaypledgeTvChannelsForm(array $form, $form_state) {
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>
                                    <li><a href="cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                                    <li><a href="cnp_form">' . $this->t("Form Groups") . '</a></li>
      <li><a class="cnpccurrent" href="CnPpledgeTVChannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                                    <li><a href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                                    </ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $html = '<div class="cnpc-btn-center"><a href="add_channel_group" class="cnpc_button_link_add">' . $this->t("Add New Channel Group") . '</a></div>';

    $form['button_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['table_group_start'] = [
      '#prefix' => '<div class="tablelist_group">',
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_tag_start'] = [
        '#prefix' => '<div><table id="table_form_group" class="table_form_group">
                            <thead>
                                <tr>
                                                          <th>' . $this->t('Group Name') . '</th>
                                                          <th>' . $this->t('Account#') . '</th>
                                  <th>Short Code <span class="cnpc_question">&#63;</span><div class="cnpc_shortcode_tooltip">Please copy this code and place it in your required content pages, posts or any custom content types. This code will run the series of the channels which has been added to this particular channel Group inside your content page.</div></th>
                                                          <th>' . $this->t('Start Date/Time') . '</th>
                                                          <th>' . $this->t('End Date/Time') . '</th>
                                                          <th>' . $this->t('Active Channel(s)') . '</th>
                                                          <th>' . $this->t('Last Modified') . '</th>
                                                          <th>' . $this->t('Status') . '</th>
                                                          <th>' . $this->t('Actions') . '</th>
                                </tr>
                            </thead>
                                                  <tbody>',
      ];
      $channelGroups = $this->getRecords();
      $rg = 1;
      foreach ($channelGroups as $fg) {
        $urlParams = ['variable' => $fg->cnpchannelgrp_ID];
        $statusParams = ['variable1' => $fg->cnpchannelgrp_status, 'variable2' => $fg->cnpchannelgrp_ID];
        if ($fg->cnpchannelgrp_channel_EndDate == '0000-00-00 00:00:00') {
          $enddate = '';
        }
        else {
          $enddate = date('F d, Y h:i:s a', strtotime($fg->cnpchannelgrp_channel_EndDate));
        }
        if ($this->checkFormsExpiry($fg->cnpchannelgrp_channel_StartDate, $enddate) === 'no') {
          $flink = "<a id='formstatus_" . $fg->cnpchannelgrp_ID . "' class='ptvformstatus' href='" . $this->cnpGenerateTokenUrl('cnpconnect.cnpc_updateptvformstatus', $statusParams) . "' data-fgid='" . $fg->cnpchannelgrp_ID . "' data-fstatus='" . $fg->cnpchannelgrp_status . "'>" . $fg->cnpchannelgrp_status . "</a>";
        }
        else {
          $flink = "<a class='ptvformstatus' href=''>" . $this->t("Expired") . "</a>";
        }
        $form['table_row_form_groups_' . $rg] = [
          '#prefix' => '<tr>
                                              <td>' . $fg->cnpchannelgrp_groupname . '</td>
                                              <td>' . $fg->cnpstngs_AccountNumber . '</td>
                                              <td>' . $fg->cnpchannelgrp_shortcode . '</td>
                                              <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpchannelgrp_channel_StartDate)) . '</td>
                                              <td>' . $enddate . '</td>
                                              <td>' . count($this->getNoofChannels($fg->cnpchannelgrp_ID)) . '</td>
                                              <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpchannelgrp_Date_Modified)) . '</td>
                                              <td>' . $flink . '</td>
                                              <td><a href="' . $this->cnpGenerateTokenUrl('cnpconnect.viewchannels', $urlParams) . '"><span class="view_icon"></span></a> | <a href="' . $this->cnpGenerateTokenUrl('cnpconnect.editchannels', $urlParams) . '"><span class="edit_icon"></span></a> | <a id="deletechannelInfo" class="deletechannelInfo" data-recid="' . $fg->cnpchannelgrp_ID . '" href="' . $this->cnpGenerateTokenUrl('cnpconnect.cnpc_deletechannelgroups', $urlParams) . '"><span class="bin_icon"></span></a> </td>',
          '#suffix' => '</tr>',
        ];
        $rg++;
      }
      $form['table_tag_end'] = [
        '#suffix' => '</tbody></table></div>',
      ];
    }
    else {
      $form['no_records'] = [
        '#prefix' => '<div><h3>' . $this->t("No Records Found.") . '</h3>',
        '#suffix' => '</div>',
      ];
    }
    $form['table_group_end'] = [
      '#suffix' => '</div>',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Saving form data handling with ajax call.
  }

  /**
   * Get pledgeTV channels from db to display into a table.
   *
   * @return array
   *   Returns channel and its settings information as an array.
   */
  public function getRecords() {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channelgrp';
    $settingstable_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT * FROM " . $table_name . " INNER JOIN " . $settingstable_name . " ON cnpchannelgrp_cnpstngs_ID=cnpstngs_ID";
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * To get the total no of channels under a form group.
   *
   * @param int $id
   *   The Channel group ID.
   *
   * @return array
   *   Returns all the channels in an array.
   */
  public function getNoofChannels($id) {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channeldtl';
    $sql = "SELECT cnpchannel_id,cnpchannel_cnpchannelgrp_ID,cnpchannel_channelName,cnpchannel_channelStartDate,"
      . "cnpchannel_channelEndDate,cnpchannel_channelStatus,cnpchannel_DateCreated,"
      . "cnpchannel_DateModified FROM " . $table_name . " where cnpchannel_cnpchannelgrp_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * Calculates expiry date of a form.
   *
   * @param mixed $startDT
   *   The Start date.
   * @param mixed $endDT
   *   The End date.
   *
   * @return string
   *   Return yes if the form is expired otherwise returns no.
   */
  public function checkFormsExpiry($startDT, $endDT) {
    date_default_timezone_set(drupal_get_user_timezone());
    $currDT = date('Y-m-d h:i:s a');
    $currDT = strtotime($currDT);
    $startDT = strtotime($startDT);
    $endDT = strtotime($endDT);
    if ($startDT > $currDT) {
      return 'no';
    }
    if ($endDT) {
      if (($currDT >= $startDT) && ($currDT <= $endDT)) {
        return 'no';
      }
      else {
        return 'yes';
      }
    }
    else {
      return 'no';
    }
  }

  /**
   * Creates an URL string with a token by appending in query string.
   *
   * @param mixed $routeName
   *   Name of the route to generate the URL.
   * @param mixed $urlParams
   *   Contains URL parameters as an array.
   *
   * @return mixed
   *   Return an absolute URL with token
   */
  public function cnpGenerateTokenUrl($routeName, $urlParams) {
    $url = Url::fromRoute($routeName, $urlParams);
    $token = $this->csrfToken->get($url->getInternalPath());
    $url->setOptions(['absolute' => TRUE, 'query' => ['token' => $token]]);
    return $url->toString();
  }

}
